# Hadiuka (Гадюка)

Пайтон по-українськи.

# Встановлення

`pip install hadiuka`

# Запуск

`hadiuka <файл>`

`hadiuka -m <модуль>`

(щоб писати українською, використовуйте файли з розширенням `.пай`)

# Приклад

```python
спробуй:
    ймення = ввід("Введи своє ім'я: ")
виняток ПомилкаКінецьФайлу:
    друк("\nЯ так не граю :(")
    вихід(1)

якщо ймення:
    друк(ф"Привіт, світе! Я {ймення}")
інакше:
    друк("Бувай!")
```
